@@ -119,6 +119,28 @@ def draw_all_box_and_label_pil(img, boxes, outline='red', width=2, text_color='w
     return img
 
 
+def draw_all_box_and_label_pil2(img, boxes, outline='red', width=2, text_color='white', text_bg_color='red', text_size=24, font_path='app/fonts/wqy-zenhei.ttc'):
+    draw = ImageDraw.Draw(img)
+    for (label, box) in boxes:
+        x1, y1, x2, y2 = box
+        draw.rectangle((x1, y1, x2, y2), outline=outline, width=width)
+
+    font = ImageFont.truetype(font_path, text_size)
+
+    for (label, box) in boxes:
+        x1 = max(box[0], 0)
+        y1 = max(box[1] - text_size - 3, 0)
+        point = (x1, y1)
+        try:
+            text_width = len(label.encode('gb2312'))
+        except:
+            text_width = len(label) + 1
+        draw.rectangle((x1, y1, x1 + text_size * text_width / 2, y1 + text_size + 3), fill=text_bg_color)
+        draw.text(point, label, text_color, font=font)  # 参数1：打印坐标，参数2：文本，参数3：字体颜色，参数4：字体
+
+    return img
+
+
 def draw_all_box(img, boxes, outline='red', width=2):
     draw = ImageDraw.Draw(img)
     for box in boxes:
@@ -128,6 +150,15 @@ def draw_all_box(img, boxes, outline='red', width=2):
     return img
 
 
+def draw_all_box2(img, boxes, outline='red', width=2):
+    draw = ImageDraw.Draw(img)
+    for box in boxes:
+        x1, y1, x2, y2 = box
+        draw.rectangle((x1, y1, x2, y2), outline=outline, width=width)
+
+    return img
+
+
 def draw_labels(img, labels, text_color='white', text_bg_color='red', text_size=24, font_path='app/fonts/wqy-zenhei.ttc'):
     draw = ImageDraw.Draw(img)  # 图片上打印
     font = ImageFont.truetype(font_path, text_size)
